"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.17.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.model.scope import Scope
globals()['Scope'] = Scope
from nuaudit_python_autogen.model.permission_mutation import PermissionMutation


class TestPermissionMutation(unittest.TestCase):
    """PermissionMutation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPermissionMutation(self):
        """Test PermissionMutation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PermissionMutation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.17.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.api_keys_api import APIKeysApi  # noqa: E501


class TestAPIKeysApi(unittest.TestCase):
    """APIKeysApi unit test stubs"""

    def setUp(self):
        self.api = APIKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_api_key(self):
        """Test case for create_api_key

        Create Api Key  # noqa: E501
        """
        pass

    def test_delete_api_key(self):
        """Test case for delete_api_key

        Delete Api Key  # noqa: E501
        """
        pass

    def test_list_api_keys_for_api_client(self):
        """Test case for list_api_keys_for_api_client

        List Api Keys For Api Client  # noqa: E501
        """
        pass

    def test_update_api_key(self):
        """Test case for update_api_key

        Update Api Key  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.17.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.settings_api import SettingsApi  # noqa: E501


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    def setUp(self):
        self.api = SettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_settings_for_organization(self):
        """Test case for get_settings_for_organization

        Get Settings For Organization  # noqa: E501
        """
        pass

    def test_update_settings_for_organization(self):
        """Test case for update_settings_for_organization

        Update Settings For Organization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
